@@ -292,6 +292,11 @@ cuesheet_widget_renderer_media_changed_cb (MafwRenderer *renderer,
 
 	g_return_if_fail (priv);
 
+	if (object_id == NULL) {
+		g_critical ("cuesheet-widget: No valid object_id available\n");
+		return;
+	}
+
 	if (priv->source == NULL) {
 		g_critical ("cuesheet-widget: Source %s is not available\n", WANTED_SOURCE);
 		return;
@@ -331,7 +336,10 @@ cuesheet_widget_renderer_current_metadata (MafwRenderer *self,
 		return;
 	}
 
-	cuesheet_widget_renderer_media_changed_cb (self, 0, object_id, priv);
+	if (object_id != NULL) {
+		cuesheet_widget_renderer_media_changed_cb (self, 0, object_id, priv);
+	}
+
 }
 
 static void
@@ -655,7 +663,6 @@ cuesheet_widget_init (CueSheetWidget *priv)
 		g_error ("cuesheet-widget: Failed to get MafwRegistry reference\n");
 		return;
 	}
-
 	/* Start out-of-process extension discovery */
 	mafw_shared_init (registry, &error);
 	if (error != NULL)
@@ -695,7 +702,6 @@ cuesheet_widget_init (CueSheetWidget *priv)
 						 G_OBJECT(extension_list->data), priv);
 		extension_list = g_list_next(extension_list);
 	}
-
 }
 
 static void
